@@ -53,7 +53,7 @@ sub BUILDARGS {
 	else { warn "Failed to parse viewBox attribute.\n"  }
     }
 
-    $args{view_box} ||= [0, 0, $args{width}, $args{height}];
+    $args{view_box} ||= [0, 0, $args{width} || 0, $args{height} || 0];
 
     return \%args;
 }
